summaryrefslogtreecommitdiff
path: root/gcc/config/i386/linux.h
diff options
context:
space:
mode:
authorkenner <kenner@138bc75d-0d04-0410-961f-82ee72b054a4>1996-01-15 13:28:30 +0000
committerkenner <kenner@138bc75d-0d04-0410-961f-82ee72b054a4>1996-01-15 13:28:30 +0000
commitf3a30d9b5452e89b4700b857df7caa448c956489 (patch)
treecdb412feb3e198165548c6c0560063fc59e4dae3 /gcc/config/i386/linux.h
parentbbc5a1b5b33c1d91f5644920a90e60c28ff53875 (diff)
downloadgcc-f3a30d9b5452e89b4700b857df7caa448c956489.tar.gz
(LIB_SPEC): Remove %{mieee-fp:-lieee}.
Use -lc_p for -profile. (CC1_SPEC): New macro. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@10984 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/i386/linux.h')
-rw-r--r--gcc/config/i386/linux.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/gcc/config/i386/linux.h b/gcc/config/i386/linux.h
index f077de57efb..b428fc91d15 100644
--- a/gcc/config/i386/linux.h
+++ b/gcc/config/i386/linux.h
@@ -1,5 +1,5 @@
/* Definitions for Intel 386 running Linux with ELF format
- Copyright (C) 1994, 1995 Free Software Foundation, Inc.
+ Copyright (C) 1994, 1995, 1996 Free Software Foundation, Inc.
Contributed by Eric Youngdale.
Modified for stabs-in-ELF by H.J. Lu.
@@ -157,15 +157,19 @@ Boston, MA 02111-1307, USA. */
#define CPP_SPEC "%{fPIC:-D__PIC__ -D__pic__} %{fpic:-D__PIC__ -D__pic__} %{m486:-D__i486__} %{posix:-D_POSIX_SOURCE}"
#endif
+/* This is for -profile to use -lc_p instead of -lc. */
+#undef CC1_SPEC
+#define CC1_SPEC "%{profile:-p}"
+
#undef LIB_SPEC
#if 1
/* We no longer link with libc_p.a or libg.a by default. If you
* want to profile or debug the Linux C library, please add
* -lc_p or -ggdb to LDFLAGS at the link time, respectively.
*/
#define LIB_SPEC \
- "%{!shared: %{mieee-fp:-lieee} %{p:-lgmon} %{pg:-lgmon} \
- %{!ggdb:-lc} %{ggdb:-lg}}"
+ "%{!shared: %{p:-lgmon} %{pg:-lgmon} %{profile:-lgmon -lc_p} \
+ %{!profile:%{!ggdb:-lc} %{ggdb:-lg}}}"
#else
#define LIB_SPEC \
"%{!shared: \
@@ -157,15 +157,19 @@ Boston, MA 02111-1307, USA. */
/* We no longer link with libc_p.a or libg.a by default. If you
* want to profile or debug the Linux C library, please add
- * -lc_p or -ggdb to LDFLAGS at the link time, respectively.
+ * -profile or -ggdb to LDFLAGS at the link time, respectively.
*/
#define LIB_SPEC \